"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Storage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_ACCOUNTS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_BLOB_SERVICES_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_BLOB_SERVICES_CONTAINERS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_FILE_SERVICES_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_MANAGEMENT_POLICIES_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_QUEUE_SERVICES_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_TABLE_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def storage_accounts(self) -> global___StorageAccounts: ...
    @property
    def storage_accounts_blob_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsBlobServices]: ...
    @property
    def storage_accounts_blob_services_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsBlobServicesContainers]: ...
    @property
    def storage_accounts_file_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsFileServices]: ...
    @property
    def storage_accounts_management_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsManagementPolicies]: ...
    @property
    def storage_accounts_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsPrivateEndpointConnections]: ...
    @property
    def storage_accounts_queue_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsQueueServices]: ...
    @property
    def storage_accounts_table_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsTableServices]: ...
    def __init__(
        self,
        *,
        storage_accounts: global___StorageAccounts | None = ...,
        storage_accounts_blob_services: collections.abc.Iterable[global___StorageAccountsBlobServices] | None = ...,
        storage_accounts_blob_services_containers: collections.abc.Iterable[global___StorageAccountsBlobServicesContainers] | None = ...,
        storage_accounts_file_services: collections.abc.Iterable[global___StorageAccountsFileServices] | None = ...,
        storage_accounts_management_policies: collections.abc.Iterable[global___StorageAccountsManagementPolicies] | None = ...,
        storage_accounts_private_endpoint_connections: collections.abc.Iterable[global___StorageAccountsPrivateEndpointConnections] | None = ...,
        storage_accounts_queue_services: collections.abc.Iterable[global___StorageAccountsQueueServices] | None = ...,
        storage_accounts_table_services: collections.abc.Iterable[global___StorageAccountsTableServices] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["storage_accounts", b"storage_accounts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["storage_accounts", b"storage_accounts", "storage_accounts_blob_services", b"storage_accounts_blob_services", "storage_accounts_blob_services_containers", b"storage_accounts_blob_services_containers", "storage_accounts_file_services", b"storage_accounts_file_services", "storage_accounts_management_policies", b"storage_accounts_management_policies", "storage_accounts_private_endpoint_connections", b"storage_accounts_private_endpoint_connections", "storage_accounts_queue_services", b"storage_accounts_queue_services", "storage_accounts_table_services", b"storage_accounts_table_services"]) -> None: ...

global___Microsoft_Storage = Microsoft_Storage

@typing_extensions.final
class StorageAccountsTableServicesTables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___StorageAccountsTableServicesTables = StorageAccountsTableServicesTables

@typing_extensions.final
class StorageAccountsTableServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_TABLE_SERVICES_TABLES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def cors(self) -> global___CorsRules: ...
    @property
    def storage_accounts_table_services_tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsTableServicesTables]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        cors: global___CorsRules | None = ...,
        storage_accounts_table_services_tables: collections.abc.Iterable[global___StorageAccountsTableServicesTables] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors", b"cors", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors", b"cors", "name", b"name", "resource_info", b"resource_info", "storage_accounts_table_services_tables", b"storage_accounts_table_services_tables"]) -> None: ...

global___StorageAccountsTableServices = StorageAccountsTableServices

@typing_extensions.final
class StorageAccountsQueueServicesQueues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___StorageAccountsQueueServicesQueues = StorageAccountsQueueServicesQueues

@typing_extensions.final
class StorageAccountsQueueServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_QUEUE_SERVICES_QUEUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def cors(self) -> global___CorsRules: ...
    @property
    def storage_accounts_queue_services_queues(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsQueueServicesQueues]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        cors: global___CorsRules | None = ...,
        storage_accounts_queue_services_queues: collections.abc.Iterable[global___StorageAccountsQueueServicesQueues] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors", b"cors", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors", b"cors", "name", b"name", "resource_info", b"resource_info", "storage_accounts_queue_services_queues", b"storage_accounts_queue_services_queues"]) -> None: ...

global___StorageAccountsQueueServices = StorageAccountsQueueServices

@typing_extensions.final
class StorageAccountsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___StorageAccountsPrivateEndpointConnections = StorageAccountsPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    action_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        action_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_required", b"action_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class StorageAccountsObjectReplicationPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESTINATION_ACCOUNT_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    SOURCE_ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    destination_account: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ObjectReplicationPolicyRule]: ...
    source_account: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        destination_account: builtins.str = ...,
        rules: collections.abc.Iterable[global___ObjectReplicationPolicyRule] | None = ...,
        source_account: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_account", b"destination_account", "name", b"name", "resource_info", b"resource_info", "rules", b"rules", "source_account", b"source_account"]) -> None: ...

global___StorageAccountsObjectReplicationPolicies = StorageAccountsObjectReplicationPolicies

@typing_extensions.final
class ObjectReplicationPolicyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_CONTAINER_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    RULE_ID_FIELD_NUMBER: builtins.int
    SOURCE_CONTAINER_FIELD_NUMBER: builtins.int
    destination_container: builtins.str
    @property
    def filters(self) -> global___ObjectReplicationPolicyFilter: ...
    rule_id: builtins.str
    source_container: builtins.str
    def __init__(
        self,
        *,
        destination_container: builtins.str = ...,
        filters: global___ObjectReplicationPolicyFilter | None = ...,
        rule_id: builtins.str = ...,
        source_container: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filters", b"filters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_container", b"destination_container", "filters", b"filters", "rule_id", b"rule_id", "source_container", b"source_container"]) -> None: ...

global___ObjectReplicationPolicyRule = ObjectReplicationPolicyRule

@typing_extensions.final
class ObjectReplicationPolicyFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_CREATION_TIME_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    min_creation_time: builtins.str
    @property
    def prefix_match(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        min_creation_time: builtins.str = ...,
        prefix_match: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_creation_time", b"min_creation_time", "prefix_match", b"prefix_match"]) -> None: ...

global___ObjectReplicationPolicyFilter = ObjectReplicationPolicyFilter

@typing_extensions.final
class StorageAccountsManagementPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def policy(self) -> global___ManagementPolicySchema: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        policy: global___ManagementPolicySchema | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["policy", b"policy", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "policy", b"policy", "resource_info", b"resource_info"]) -> None: ...

global___StorageAccountsManagementPolicies = StorageAccountsManagementPolicies

@typing_extensions.final
class ManagementPolicySchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULES_FIELD_NUMBER: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagementPolicyRule]: ...
    def __init__(
        self,
        *,
        rules: collections.abc.Iterable[global___ManagementPolicyRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rules", b"rules"]) -> None: ...

global___ManagementPolicySchema = ManagementPolicySchema

@typing_extensions.final
class ManagementPolicyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFINITION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def definition(self) -> global___ManagementPolicyDefinition: ...
    enabled: builtins.bool
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        definition: global___ManagementPolicyDefinition | None = ...,
        enabled: builtins.bool = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition", b"definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "enabled", b"enabled", "name", b"name", "type", b"type"]) -> None: ...

global___ManagementPolicyRule = ManagementPolicyRule

@typing_extensions.final
class ManagementPolicyDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    @property
    def actions(self) -> global___ManagementPolicyAction: ...
    @property
    def filters(self) -> global___ManagementPolicyFilter: ...
    def __init__(
        self,
        *,
        actions: global___ManagementPolicyAction | None = ...,
        filters: global___ManagementPolicyFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["actions", b"actions", "filters", b"filters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "filters", b"filters"]) -> None: ...

global___ManagementPolicyDefinition = ManagementPolicyDefinition

@typing_extensions.final
class ManagementPolicyFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOB_INDEX_MATCH_FIELD_NUMBER: builtins.int
    BLOB_TYPES_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    @property
    def blob_index_match(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TagFilter]: ...
    @property
    def blob_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def prefix_match(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        blob_index_match: collections.abc.Iterable[global___TagFilter] | None = ...,
        blob_types: collections.abc.Iterable[builtins.str] | None = ...,
        prefix_match: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob_index_match", b"blob_index_match", "blob_types", b"blob_types", "prefix_match", b"prefix_match"]) -> None: ...

global___ManagementPolicyFilter = ManagementPolicyFilter

@typing_extensions.final
class TagFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OP_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    op: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        op: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "op", b"op", "value", b"value"]) -> None: ...

global___TagFilter = TagFilter

@typing_extensions.final
class ManagementPolicyAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_BLOB_FIELD_NUMBER: builtins.int
    SNAPSHOT_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def base_blob(self) -> global___ManagementPolicyBaseBlob: ...
    @property
    def snapshot(self) -> global___ManagementPolicySnapShot: ...
    @property
    def version(self) -> global___ManagementPolicyVersion: ...
    def __init__(
        self,
        *,
        base_blob: global___ManagementPolicyBaseBlob | None = ...,
        snapshot: global___ManagementPolicySnapShot | None = ...,
        version: global___ManagementPolicyVersion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_blob", b"base_blob", "snapshot", b"snapshot", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_blob", b"base_blob", "snapshot", b"snapshot", "version", b"version"]) -> None: ...

global___ManagementPolicyAction = ManagementPolicyAction

@typing_extensions.final
class ManagementPolicyVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETE_FIELD_NUMBER: builtins.int
    TIER_TO_ARCHIVE_FIELD_NUMBER: builtins.int
    TIER_TO_COOL_FIELD_NUMBER: builtins.int
    @property
    def delete(self) -> global___DateAfterCreation: ...
    @property
    def tier_to_archive(self) -> global___DateAfterCreation: ...
    @property
    def tier_to_cool(self) -> global___DateAfterCreation: ...
    def __init__(
        self,
        *,
        delete: global___DateAfterCreation | None = ...,
        tier_to_archive: global___DateAfterCreation | None = ...,
        tier_to_cool: global___DateAfterCreation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delete", b"delete", "tier_to_archive", b"tier_to_archive", "tier_to_cool", b"tier_to_cool"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete", b"delete", "tier_to_archive", b"tier_to_archive", "tier_to_cool", b"tier_to_cool"]) -> None: ...

global___ManagementPolicyVersion = ManagementPolicyVersion

@typing_extensions.final
class ManagementPolicySnapShot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETE_FIELD_NUMBER: builtins.int
    TIER_TO_ARCHIVE_FIELD_NUMBER: builtins.int
    TIER_TO_COOL_FIELD_NUMBER: builtins.int
    @property
    def delete(self) -> global___DateAfterCreation: ...
    @property
    def tier_to_archive(self) -> global___DateAfterCreation: ...
    @property
    def tier_to_cool(self) -> global___DateAfterCreation: ...
    def __init__(
        self,
        *,
        delete: global___DateAfterCreation | None = ...,
        tier_to_archive: global___DateAfterCreation | None = ...,
        tier_to_cool: global___DateAfterCreation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delete", b"delete", "tier_to_archive", b"tier_to_archive", "tier_to_cool", b"tier_to_cool"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete", b"delete", "tier_to_archive", b"tier_to_archive", "tier_to_cool", b"tier_to_cool"]) -> None: ...

global___ManagementPolicySnapShot = ManagementPolicySnapShot

@typing_extensions.final
class DateAfterCreation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_AFTER_CREATION_GREATER_THAN_FIELD_NUMBER: builtins.int
    days_after_creation_greater_than: builtins.float
    def __init__(
        self,
        *,
        days_after_creation_greater_than: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days_after_creation_greater_than", b"days_after_creation_greater_than"]) -> None: ...

global___DateAfterCreation = DateAfterCreation

@typing_extensions.final
class ManagementPolicyBaseBlob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETE_FIELD_NUMBER: builtins.int
    ENABLE_AUTO_TIER_TO_HOT_FROM_COOL_FIELD_NUMBER: builtins.int
    TIER_TO_ARCHIVE_FIELD_NUMBER: builtins.int
    TIER_TO_COOL_FIELD_NUMBER: builtins.int
    @property
    def delete(self) -> global___DateAfterModification: ...
    enable_auto_tier_to_hot_from_cool: builtins.bool
    @property
    def tier_to_archive(self) -> global___DateAfterModification: ...
    @property
    def tier_to_cool(self) -> global___DateAfterModification: ...
    def __init__(
        self,
        *,
        delete: global___DateAfterModification | None = ...,
        enable_auto_tier_to_hot_from_cool: builtins.bool = ...,
        tier_to_archive: global___DateAfterModification | None = ...,
        tier_to_cool: global___DateAfterModification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delete", b"delete", "tier_to_archive", b"tier_to_archive", "tier_to_cool", b"tier_to_cool"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete", b"delete", "enable_auto_tier_to_hot_from_cool", b"enable_auto_tier_to_hot_from_cool", "tier_to_archive", b"tier_to_archive", "tier_to_cool", b"tier_to_cool"]) -> None: ...

global___ManagementPolicyBaseBlob = ManagementPolicyBaseBlob

@typing_extensions.final
class DateAfterModification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_AFTER_LAST_ACCESS_TIME_GREATER_THAN_FIELD_NUMBER: builtins.int
    DAYS_AFTER_MODIFICATION_GREATER_THAN_FIELD_NUMBER: builtins.int
    days_after_last_access_time_greater_than: builtins.float
    days_after_modification_greater_than: builtins.float
    def __init__(
        self,
        *,
        days_after_last_access_time_greater_than: builtins.float = ...,
        days_after_modification_greater_than: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days_after_last_access_time_greater_than", b"days_after_last_access_time_greater_than", "days_after_modification_greater_than", b"days_after_modification_greater_than"]) -> None: ...

global___DateAfterModification = DateAfterModification

@typing_extensions.final
class StorageAccountsLocalUsers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HAS_SHARED_KEY_FIELD_NUMBER: builtins.int
    HAS_SSH_KEY_FIELD_NUMBER: builtins.int
    HAS_SSH_PASSWORD_FIELD_NUMBER: builtins.int
    HOME_DIRECTORY_FIELD_NUMBER: builtins.int
    PERMISSION_SCOPES_FIELD_NUMBER: builtins.int
    SSH_AUTHORIZED_KEYS_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    has_shared_key: builtins.bool
    has_ssh_key: builtins.bool
    has_ssh_password: builtins.bool
    home_directory: builtins.str
    @property
    def permission_scopes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PermissionScope]: ...
    @property
    def ssh_authorized_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SshPublicKey]: ...
    @property
    def system_data(self) -> global___SystemData: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        has_shared_key: builtins.bool = ...,
        has_ssh_key: builtins.bool = ...,
        has_ssh_password: builtins.bool = ...,
        home_directory: builtins.str = ...,
        permission_scopes: collections.abc.Iterable[global___PermissionScope] | None = ...,
        ssh_authorized_keys: collections.abc.Iterable[global___SshPublicKey] | None = ...,
        system_data: global___SystemData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_shared_key", b"has_shared_key", "has_ssh_key", b"has_ssh_key", "has_ssh_password", b"has_ssh_password", "home_directory", b"home_directory", "name", b"name", "permission_scopes", b"permission_scopes", "resource_info", b"resource_info", "ssh_authorized_keys", b"ssh_authorized_keys", "system_data", b"system_data"]) -> None: ...

global___StorageAccountsLocalUsers = StorageAccountsLocalUsers

@typing_extensions.final
class SshPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    description: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "key", b"key"]) -> None: ...

global___SshPublicKey = SshPublicKey

@typing_extensions.final
class PermissionScope(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERMISSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    permissions: builtins.str
    resource_name: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        permissions: builtins.str = ...,
        resource_name: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["permissions", b"permissions", "resource_name", b"resource_name", "service", b"service"]) -> None: ...

global___PermissionScope = PermissionScope

@typing_extensions.final
class StorageAccountsInventoryPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def policy(self) -> global___BlobInventoryPolicySchema: ...
    @property
    def system_data(self) -> global___SystemData: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        policy: global___BlobInventoryPolicySchema | None = ...,
        system_data: global___SystemData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["policy", b"policy", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "policy", b"policy", "resource_info", b"resource_info", "system_data", b"system_data"]) -> None: ...

global___StorageAccountsInventoryPolicies = StorageAccountsInventoryPolicies

@typing_extensions.final
class SystemData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_BY_TYPE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_TYPE_FIELD_NUMBER: builtins.int
    created_at: builtins.str
    created_by: builtins.str
    created_by_type: builtins.str
    last_modified_at: builtins.str
    last_modified_by: builtins.str
    last_modified_by_type: builtins.str
    def __init__(
        self,
        *,
        created_at: builtins.str = ...,
        created_by: builtins.str = ...,
        created_by_type: builtins.str = ...,
        last_modified_at: builtins.str = ...,
        last_modified_by: builtins.str = ...,
        last_modified_by_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "created_by_type", b"created_by_type", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by", "last_modified_by_type", b"last_modified_by_type"]) -> None: ...

global___SystemData = SystemData

@typing_extensions.final
class BlobInventoryPolicySchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BlobInventoryPolicyRule]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        rules: collections.abc.Iterable[global___BlobInventoryPolicyRule] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "rules", b"rules", "type", b"type"]) -> None: ...

global___BlobInventoryPolicySchema = BlobInventoryPolicySchema

@typing_extensions.final
class BlobInventoryPolicyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFINITION_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def definition(self) -> global___BlobInventoryPolicyDefinition: ...
    destination: builtins.str
    enabled: builtins.bool
    name: builtins.str
    def __init__(
        self,
        *,
        definition: global___BlobInventoryPolicyDefinition | None = ...,
        destination: builtins.str = ...,
        enabled: builtins.bool = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition", b"definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "destination", b"destination", "enabled", b"enabled", "name", b"name"]) -> None: ...

global___BlobInventoryPolicyRule = BlobInventoryPolicyRule

@typing_extensions.final
class BlobInventoryPolicyDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTERS_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    OBJECT_TYPE_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELDS_FIELD_NUMBER: builtins.int
    @property
    def filters(self) -> global___BlobInventoryPolicyFilter: ...
    format: builtins.str
    object_type: builtins.str
    schedule: builtins.str
    @property
    def schema_fields(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        filters: global___BlobInventoryPolicyFilter | None = ...,
        format: builtins.str = ...,
        object_type: builtins.str = ...,
        schedule: builtins.str = ...,
        schema_fields: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filters", b"filters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filters", b"filters", "format", b"format", "object_type", b"object_type", "schedule", b"schedule", "schema_fields", b"schema_fields"]) -> None: ...

global___BlobInventoryPolicyDefinition = BlobInventoryPolicyDefinition

@typing_extensions.final
class BlobInventoryPolicyFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOB_TYPES_FIELD_NUMBER: builtins.int
    INCLUDE_BLOB_VERSIONS_FIELD_NUMBER: builtins.int
    INCLUDE_SNAPSHOTS_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    @property
    def blob_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    include_blob_versions: builtins.bool
    include_snapshots: builtins.bool
    @property
    def prefix_match(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        blob_types: collections.abc.Iterable[builtins.str] | None = ...,
        include_blob_versions: builtins.bool = ...,
        include_snapshots: builtins.bool = ...,
        prefix_match: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob_types", b"blob_types", "include_blob_versions", b"include_blob_versions", "include_snapshots", b"include_snapshots", "prefix_match", b"prefix_match"]) -> None: ...

global___BlobInventoryPolicyFilter = BlobInventoryPolicyFilter

@typing_extensions.final
class StorageAccountsFileServicesShares(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACCESS_TIER_FIELD_NUMBER: builtins.int
    ENABLED_PROTOCOLS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    ROOT_SQUASH_FIELD_NUMBER: builtins.int
    SHARE_QUOTA_FIELD_NUMBER: builtins.int
    SIGNED_IDENTIFIERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    access_tier: builtins.str
    enabled_protocols: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    root_squash: builtins.str
    share_quota: builtins.int
    @property
    def signed_identifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SignedIdentifier]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        access_tier: builtins.str = ...,
        enabled_protocols: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        root_squash: builtins.str = ...,
        share_quota: builtins.int = ...,
        signed_identifiers: collections.abc.Iterable[global___SignedIdentifier] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_tier", b"access_tier", "enabled_protocols", b"enabled_protocols", "metadata", b"metadata", "name", b"name", "resource_info", b"resource_info", "root_squash", b"root_squash", "share_quota", b"share_quota", "signed_identifiers", b"signed_identifiers"]) -> None: ...

global___StorageAccountsFileServicesShares = StorageAccountsFileServicesShares

@typing_extensions.final
class SignedIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_POLICY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    @property
    def access_policy(self) -> global___AccessPolicy: ...
    id: builtins.str
    def __init__(
        self,
        *,
        access_policy: global___AccessPolicy | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_policy", b"access_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_policy", b"access_policy", "id", b"id"]) -> None: ...

global___SignedIdentifier = SignedIdentifier

@typing_extensions.final
class AccessPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRY_TIME_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    expiry_time: builtins.str
    permission: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        expiry_time: builtins.str = ...,
        permission: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiry_time", b"expiry_time", "permission", b"permission", "start_time", b"start_time"]) -> None: ...

global___AccessPolicy = AccessPolicy

@typing_extensions.final
class StorageAccountsFileServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    PROTOCOL_SETTINGS_FIELD_NUMBER: builtins.int
    SHARE_DELETE_RETENTION_POLICY_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_FILE_SERVICES_SHARES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def cors(self) -> global___CorsRules: ...
    @property
    def protocol_settings(self) -> global___ProtocolSettings: ...
    @property
    def share_delete_retention_policy(self) -> global___DeleteRetentionPolicy: ...
    @property
    def storage_accounts_file_services_shares(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsFileServicesShares]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        cors: global___CorsRules | None = ...,
        protocol_settings: global___ProtocolSettings | None = ...,
        share_delete_retention_policy: global___DeleteRetentionPolicy | None = ...,
        storage_accounts_file_services_shares: collections.abc.Iterable[global___StorageAccountsFileServicesShares] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors", b"cors", "protocol_settings", b"protocol_settings", "resource_info", b"resource_info", "share_delete_retention_policy", b"share_delete_retention_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors", b"cors", "name", b"name", "protocol_settings", b"protocol_settings", "resource_info", b"resource_info", "share_delete_retention_policy", b"share_delete_retention_policy", "storage_accounts_file_services_shares", b"storage_accounts_file_services_shares"]) -> None: ...

global___StorageAccountsFileServices = StorageAccountsFileServices

@typing_extensions.final
class ProtocolSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SMB_FIELD_NUMBER: builtins.int
    @property
    def smb(self) -> global___SmbSetting: ...
    def __init__(
        self,
        *,
        smb: global___SmbSetting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["smb", b"smb"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["smb", b"smb"]) -> None: ...

global___ProtocolSettings = ProtocolSettings

@typing_extensions.final
class SmbSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_METHODS_FIELD_NUMBER: builtins.int
    CHANNEL_ENCRYPTION_FIELD_NUMBER: builtins.int
    KERBEROS_TICKET_ENCRYPTION_FIELD_NUMBER: builtins.int
    MULTICHANNEL_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    authentication_methods: builtins.str
    channel_encryption: builtins.str
    kerberos_ticket_encryption: builtins.str
    @property
    def multichannel(self) -> global___Multichannel: ...
    versions: builtins.str
    def __init__(
        self,
        *,
        authentication_methods: builtins.str = ...,
        channel_encryption: builtins.str = ...,
        kerberos_ticket_encryption: builtins.str = ...,
        multichannel: global___Multichannel | None = ...,
        versions: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["multichannel", b"multichannel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_methods", b"authentication_methods", "channel_encryption", b"channel_encryption", "kerberos_ticket_encryption", b"kerberos_ticket_encryption", "multichannel", b"multichannel", "versions", b"versions"]) -> None: ...

global___SmbSetting = SmbSetting

@typing_extensions.final
class Multichannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___Multichannel = Multichannel

@typing_extensions.final
class StorageAccountsEncryptionScopes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    KEY_VAULT_PROPERTIES_FIELD_NUMBER: builtins.int
    REQUIRE_INFRASTRUCTURE_ENCRYPTION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def key_vault_properties(self) -> global___EncryptionScopeKeyVaultProperties: ...
    require_infrastructure_encryption: builtins.bool
    source: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        key_vault_properties: global___EncryptionScopeKeyVaultProperties | None = ...,
        require_infrastructure_encryption: builtins.bool = ...,
        source: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_vault_properties", b"key_vault_properties", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_properties", b"key_vault_properties", "name", b"name", "require_infrastructure_encryption", b"require_infrastructure_encryption", "resource_info", b"resource_info", "source", b"source", "state", b"state"]) -> None: ...

global___StorageAccountsEncryptionScopes = StorageAccountsEncryptionScopes

@typing_extensions.final
class EncryptionScopeKeyVaultProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_URI_FIELD_NUMBER: builtins.int
    key_uri: builtins.str
    def __init__(
        self,
        *,
        key_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_uri", b"key_uri"]) -> None: ...

global___EncryptionScopeKeyVaultProperties = EncryptionScopeKeyVaultProperties

@typing_extensions.final
class StorageAccountsBlobServicesContainersImmutabilityPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOW_PROTECTED_APPEND_WRITES_FIELD_NUMBER: builtins.int
    ALLOW_PROTECTED_APPEND_WRITES_ALL_FIELD_NUMBER: builtins.int
    IMMUTABILITY_PERIOD_SINCE_CREATION_IN_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    allow_protected_append_writes: builtins.bool
    allow_protected_append_writes_all: builtins.bool
    immutability_period_since_creation_in_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        allow_protected_append_writes: builtins.bool = ...,
        allow_protected_append_writes_all: builtins.bool = ...,
        immutability_period_since_creation_in_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_protected_append_writes", b"allow_protected_append_writes", "allow_protected_append_writes_all", b"allow_protected_append_writes_all", "immutability_period_since_creation_in_days", b"immutability_period_since_creation_in_days", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___StorageAccountsBlobServicesContainersImmutabilityPolicies = StorageAccountsBlobServicesContainersImmutabilityPolicies

@typing_extensions.final
class StorageAccountsBlobServicesContainers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEFAULT_ENCRYPTION_SCOPE_FIELD_NUMBER: builtins.int
    DENY_ENCRYPTION_SCOPE_OVERRIDE_FIELD_NUMBER: builtins.int
    ENABLE_NFS_V3_ALL_SQUASH_FIELD_NUMBER: builtins.int
    ENABLE_NFS_V3_ROOT_SQUASH_FIELD_NUMBER: builtins.int
    IMMUTABLE_STORAGE_WITH_VERSIONING_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_BLOB_SERVICES_CONTAINERS_IMMUTABILITY_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    default_encryption_scope: builtins.str
    deny_encryption_scope_override: builtins.bool
    enable_nfs_v3_all_squash: builtins.bool
    enable_nfs_v3_root_squash: builtins.bool
    @property
    def immutable_storage_with_versioning(self) -> global___ImmutableStorageWithVersioning: ...
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    public_access: builtins.str
    @property
    def storage_accounts_blob_services_containers_immutability_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsBlobServicesContainersImmutabilityPolicies]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        default_encryption_scope: builtins.str = ...,
        deny_encryption_scope_override: builtins.bool = ...,
        enable_nfs_v3_all_squash: builtins.bool = ...,
        enable_nfs_v3_root_squash: builtins.bool = ...,
        immutable_storage_with_versioning: global___ImmutableStorageWithVersioning | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        public_access: builtins.str = ...,
        storage_accounts_blob_services_containers_immutability_policies: collections.abc.Iterable[global___StorageAccountsBlobServicesContainersImmutabilityPolicies] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["immutable_storage_with_versioning", b"immutable_storage_with_versioning", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_encryption_scope", b"default_encryption_scope", "deny_encryption_scope_override", b"deny_encryption_scope_override", "enable_nfs_v3_all_squash", b"enable_nfs_v3_all_squash", "enable_nfs_v3_root_squash", b"enable_nfs_v3_root_squash", "immutable_storage_with_versioning", b"immutable_storage_with_versioning", "metadata", b"metadata", "name", b"name", "public_access", b"public_access", "resource_info", b"resource_info", "storage_accounts_blob_services_containers_immutability_policies", b"storage_accounts_blob_services_containers_immutability_policies"]) -> None: ...

global___StorageAccountsBlobServicesContainers = StorageAccountsBlobServicesContainers

@typing_extensions.final
class ImmutableStorageWithVersioning(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ImmutableStorageWithVersioning = ImmutableStorageWithVersioning

@typing_extensions.final
class StorageAccountsBlobServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTOMATIC_SNAPSHOT_POLICY_ENABLED_FIELD_NUMBER: builtins.int
    CHANGE_FEED_FIELD_NUMBER: builtins.int
    CONTAINER_DELETE_RETENTION_POLICY_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    DEFAULT_SERVICE_VERSION_FIELD_NUMBER: builtins.int
    DELETE_RETENTION_POLICY_FIELD_NUMBER: builtins.int
    IS_VERSIONING_ENABLED_FIELD_NUMBER: builtins.int
    LAST_ACCESS_TIME_TRACKING_POLICY_FIELD_NUMBER: builtins.int
    RESTORE_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    automatic_snapshot_policy_enabled: builtins.bool
    @property
    def change_feed(self) -> global___ChangeFeed: ...
    @property
    def container_delete_retention_policy(self) -> global___DeleteRetentionPolicy: ...
    @property
    def cors(self) -> global___CorsRules: ...
    default_service_version: builtins.str
    @property
    def delete_retention_policy(self) -> global___DeleteRetentionPolicy: ...
    is_versioning_enabled: builtins.bool
    @property
    def last_access_time_tracking_policy(self) -> global___LastAccessTimeTrackingPolicy: ...
    @property
    def restore_policy(self) -> global___RestorePolicyProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        automatic_snapshot_policy_enabled: builtins.bool = ...,
        change_feed: global___ChangeFeed | None = ...,
        container_delete_retention_policy: global___DeleteRetentionPolicy | None = ...,
        cors: global___CorsRules | None = ...,
        default_service_version: builtins.str = ...,
        delete_retention_policy: global___DeleteRetentionPolicy | None = ...,
        is_versioning_enabled: builtins.bool = ...,
        last_access_time_tracking_policy: global___LastAccessTimeTrackingPolicy | None = ...,
        restore_policy: global___RestorePolicyProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["change_feed", b"change_feed", "container_delete_retention_policy", b"container_delete_retention_policy", "cors", b"cors", "delete_retention_policy", b"delete_retention_policy", "last_access_time_tracking_policy", b"last_access_time_tracking_policy", "resource_info", b"resource_info", "restore_policy", b"restore_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic_snapshot_policy_enabled", b"automatic_snapshot_policy_enabled", "change_feed", b"change_feed", "container_delete_retention_policy", b"container_delete_retention_policy", "cors", b"cors", "default_service_version", b"default_service_version", "delete_retention_policy", b"delete_retention_policy", "is_versioning_enabled", b"is_versioning_enabled", "last_access_time_tracking_policy", b"last_access_time_tracking_policy", "name", b"name", "resource_info", b"resource_info", "restore_policy", b"restore_policy"]) -> None: ...

global___StorageAccountsBlobServices = StorageAccountsBlobServices

@typing_extensions.final
class RestorePolicyProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    days: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        days: builtins.int = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days", b"days", "enabled", b"enabled"]) -> None: ...

global___RestorePolicyProperties = RestorePolicyProperties

@typing_extensions.final
class LastAccessTimeTrackingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOB_TYPE_FIELD_NUMBER: builtins.int
    ENABLE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TRACKING_GRANULARITY_IN_DAYS_FIELD_NUMBER: builtins.int
    @property
    def blob_type(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable: builtins.bool
    name: builtins.str
    tracking_granularity_in_days: builtins.int
    def __init__(
        self,
        *,
        blob_type: collections.abc.Iterable[builtins.str] | None = ...,
        enable: builtins.bool = ...,
        name: builtins.str = ...,
        tracking_granularity_in_days: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob_type", b"blob_type", "enable", b"enable", "name", b"name", "tracking_granularity_in_days", b"tracking_granularity_in_days"]) -> None: ...

global___LastAccessTimeTrackingPolicy = LastAccessTimeTrackingPolicy

@typing_extensions.final
class CorsRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORS_RULES_FIELD_NUMBER: builtins.int
    @property
    def cors_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CorsRule]: ...
    def __init__(
        self,
        *,
        cors_rules: collections.abc.Iterable[global___CorsRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors_rules", b"cors_rules"]) -> None: ...

global___CorsRules = CorsRules

@typing_extensions.final
class CorsRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_HEADERS_FIELD_NUMBER: builtins.int
    ALLOWED_METHODS_FIELD_NUMBER: builtins.int
    ALLOWED_ORIGINS_FIELD_NUMBER: builtins.int
    EXPOSED_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def allowed_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allowed_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allowed_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def exposed_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age_in_seconds: builtins.int
    def __init__(
        self,
        *,
        allowed_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allowed_methods: collections.abc.Iterable[builtins.str] | None = ...,
        allowed_origins: collections.abc.Iterable[builtins.str] | None = ...,
        exposed_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age_in_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_headers", b"allowed_headers", "allowed_methods", b"allowed_methods", "allowed_origins", b"allowed_origins", "exposed_headers", b"exposed_headers", "max_age_in_seconds", b"max_age_in_seconds"]) -> None: ...

global___CorsRule = CorsRule

@typing_extensions.final
class DeleteRetentionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    days: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        days: builtins.int = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days", b"days", "enabled", b"enabled"]) -> None: ...

global___DeleteRetentionPolicy = DeleteRetentionPolicy

@typing_extensions.final
class ChangeFeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    RETENTION_IN_DAYS_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    retention_in_days: builtins.int
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        retention_in_days: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "retention_in_days", b"retention_in_days"]) -> None: ...

global___ChangeFeed = ChangeFeed

@typing_extensions.final
class StorageAccounts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACCESS_TIER_FIELD_NUMBER: builtins.int
    ALLOW_BLOB_PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    ALLOW_CROSS_TENANT_REPLICATION_FIELD_NUMBER: builtins.int
    ALLOWED_COPY_SCOPE_FIELD_NUMBER: builtins.int
    ALLOW_SHARED_KEY_ACCESS_FIELD_NUMBER: builtins.int
    AZURE_FILES_IDENTITY_BASED_AUTHENTICATION_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAIN_FIELD_NUMBER: builtins.int
    DEFAULT_TO_O_AUTH_AUTHENTICATION_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    IMMUTABLE_STORAGE_WITH_VERSIONING_FIELD_NUMBER: builtins.int
    IS_HNS_ENABLED_FIELD_NUMBER: builtins.int
    IS_LOCAL_USER_ENABLED_FIELD_NUMBER: builtins.int
    IS_NFS_V3_ENABLED_FIELD_NUMBER: builtins.int
    IS_SFTP_ENABLED_FIELD_NUMBER: builtins.int
    KEY_POLICY_FIELD_NUMBER: builtins.int
    LARGE_FILE_SHARES_STATE_FIELD_NUMBER: builtins.int
    MINIMUM_TLS_VERSION_FIELD_NUMBER: builtins.int
    NETWORK_ACLS_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    ROUTING_PREFERENCE_FIELD_NUMBER: builtins.int
    SAS_POLICY_FIELD_NUMBER: builtins.int
    SUPPORTS_HTTPS_TRAFFIC_ONLY_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_INVENTORY_POLICIES_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_OBJECT_REPLICATION_POLICIES_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_LOCAL_USERS_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNTS_ENCRYPTION_SCOPES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def identity(self) -> global___Identity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    access_tier: builtins.str
    allow_blob_public_access: builtins.bool
    allow_cross_tenant_replication: builtins.bool
    allowed_copy_scope: builtins.str
    allow_shared_key_access: builtins.bool
    @property
    def azure_files_identity_based_authentication(self) -> global___AzureFilesIdentityBasedAuthentication: ...
    @property
    def custom_domain(self) -> global___CustomDomain: ...
    default_to_o_auth_authentication: builtins.bool
    @property
    def encryption(self) -> global___Encryption: ...
    @property
    def immutable_storage_with_versioning(self) -> global___ImmutableStorageAccount: ...
    is_hns_enabled: builtins.bool
    is_local_user_enabled: builtins.bool
    is_nfs_v3_enabled: builtins.bool
    is_sftp_enabled: builtins.bool
    @property
    def key_policy(self) -> global___KeyPolicy: ...
    large_file_shares_state: builtins.str
    minimum_tls_version: builtins.str
    @property
    def network_acls(self) -> global___NetworkRuleSet: ...
    public_network_access: builtins.str
    @property
    def routing_preference(self) -> global___RoutingPreference: ...
    @property
    def sas_policy(self) -> global___SasPolicy: ...
    supports_https_traffic_only: builtins.bool
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def storage_accounts_inventory_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsInventoryPolicies]: ...
    @property
    def storage_accounts_object_replication_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsObjectReplicationPolicies]: ...
    @property
    def storage_accounts_local_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsLocalUsers]: ...
    @property
    def storage_accounts_encryption_scopes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageAccountsEncryptionScopes]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        identity: global___Identity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        access_tier: builtins.str = ...,
        allow_blob_public_access: builtins.bool = ...,
        allow_cross_tenant_replication: builtins.bool = ...,
        allowed_copy_scope: builtins.str = ...,
        allow_shared_key_access: builtins.bool = ...,
        azure_files_identity_based_authentication: global___AzureFilesIdentityBasedAuthentication | None = ...,
        custom_domain: global___CustomDomain | None = ...,
        default_to_o_auth_authentication: builtins.bool = ...,
        encryption: global___Encryption | None = ...,
        immutable_storage_with_versioning: global___ImmutableStorageAccount | None = ...,
        is_hns_enabled: builtins.bool = ...,
        is_local_user_enabled: builtins.bool = ...,
        is_nfs_v3_enabled: builtins.bool = ...,
        is_sftp_enabled: builtins.bool = ...,
        key_policy: global___KeyPolicy | None = ...,
        large_file_shares_state: builtins.str = ...,
        minimum_tls_version: builtins.str = ...,
        network_acls: global___NetworkRuleSet | None = ...,
        public_network_access: builtins.str = ...,
        routing_preference: global___RoutingPreference | None = ...,
        sas_policy: global___SasPolicy | None = ...,
        supports_https_traffic_only: builtins.bool = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        storage_accounts_inventory_policies: collections.abc.Iterable[global___StorageAccountsInventoryPolicies] | None = ...,
        storage_accounts_object_replication_policies: collections.abc.Iterable[global___StorageAccountsObjectReplicationPolicies] | None = ...,
        storage_accounts_local_users: collections.abc.Iterable[global___StorageAccountsLocalUsers] | None = ...,
        storage_accounts_encryption_scopes: collections.abc.Iterable[global___StorageAccountsEncryptionScopes] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_files_identity_based_authentication", b"azure_files_identity_based_authentication", "custom_domain", b"custom_domain", "encryption", b"encryption", "extended_location", b"extended_location", "identity", b"identity", "immutable_storage_with_versioning", b"immutable_storage_with_versioning", "key_policy", b"key_policy", "network_acls", b"network_acls", "resource_info", b"resource_info", "routing_preference", b"routing_preference", "sas_policy", b"sas_policy", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_tier", b"access_tier", "allow_blob_public_access", b"allow_blob_public_access", "allow_cross_tenant_replication", b"allow_cross_tenant_replication", "allow_shared_key_access", b"allow_shared_key_access", "allowed_copy_scope", b"allowed_copy_scope", "azure_files_identity_based_authentication", b"azure_files_identity_based_authentication", "custom_domain", b"custom_domain", "default_to_o_auth_authentication", b"default_to_o_auth_authentication", "encryption", b"encryption", "extended_location", b"extended_location", "identity", b"identity", "immutable_storage_with_versioning", b"immutable_storage_with_versioning", "is_hns_enabled", b"is_hns_enabled", "is_local_user_enabled", b"is_local_user_enabled", "is_nfs_v3_enabled", b"is_nfs_v3_enabled", "is_sftp_enabled", b"is_sftp_enabled", "key_policy", b"key_policy", "kind", b"kind", "large_file_shares_state", b"large_file_shares_state", "location", b"location", "minimum_tls_version", b"minimum_tls_version", "name", b"name", "network_acls", b"network_acls", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "routing_preference", b"routing_preference", "sas_policy", b"sas_policy", "sku", b"sku", "storage_accounts_encryption_scopes", b"storage_accounts_encryption_scopes", "storage_accounts_inventory_policies", b"storage_accounts_inventory_policies", "storage_accounts_local_users", b"storage_accounts_local_users", "storage_accounts_object_replication_policies", b"storage_accounts_object_replication_policies", "supports_https_traffic_only", b"supports_https_traffic_only", "tags", b"tags"]) -> None: ...

global___StorageAccounts = StorageAccounts

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    name: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "tier", b"tier"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class SasPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_ACTION_FIELD_NUMBER: builtins.int
    SAS_EXPIRATION_PERIOD_FIELD_NUMBER: builtins.int
    expiration_action: builtins.str
    sas_expiration_period: builtins.str
    def __init__(
        self,
        *,
        expiration_action: builtins.str = ...,
        sas_expiration_period: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_action", b"expiration_action", "sas_expiration_period", b"sas_expiration_period"]) -> None: ...

global___SasPolicy = SasPolicy

@typing_extensions.final
class RoutingPreference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLISH_INTERNET_ENDPOINTS_FIELD_NUMBER: builtins.int
    PUBLISH_MICROSOFT_ENDPOINTS_FIELD_NUMBER: builtins.int
    ROUTING_CHOICE_FIELD_NUMBER: builtins.int
    publish_internet_endpoints: builtins.bool
    publish_microsoft_endpoints: builtins.bool
    routing_choice: builtins.str
    def __init__(
        self,
        *,
        publish_internet_endpoints: builtins.bool = ...,
        publish_microsoft_endpoints: builtins.bool = ...,
        routing_choice: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["publish_internet_endpoints", b"publish_internet_endpoints", "publish_microsoft_endpoints", b"publish_microsoft_endpoints", "routing_choice", b"routing_choice"]) -> None: ...

global___RoutingPreference = RoutingPreference

@typing_extensions.final
class NetworkRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYPASS_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    RESOURCE_ACCESS_RULES_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    bypass: builtins.str
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IPRule]: ...
    @property
    def resource_access_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceAccessRule]: ...
    @property
    def virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualNetworkRule]: ...
    def __init__(
        self,
        *,
        bypass: builtins.str = ...,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___IPRule] | None = ...,
        resource_access_rules: collections.abc.Iterable[global___ResourceAccessRule] | None = ...,
        virtual_network_rules: collections.abc.Iterable[global___VirtualNetworkRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass", b"bypass", "default_action", b"default_action", "ip_rules", b"ip_rules", "resource_access_rules", b"resource_access_rules", "virtual_network_rules", b"virtual_network_rules"]) -> None: ...

global___NetworkRuleSet = NetworkRuleSet

@typing_extensions.final
class VirtualNetworkRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    action: builtins.str
    id: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        id: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "id", b"id", "state", b"state"]) -> None: ...

global___VirtualNetworkRule = VirtualNetworkRule

@typing_extensions.final
class ResourceAccessRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_id", b"resource_id", "tenant_id", b"tenant_id"]) -> None: ...

global___ResourceAccessRule = ResourceAccessRule

@typing_extensions.final
class IPRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    action: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "value", b"value"]) -> None: ...

global___IPRule = IPRule

@typing_extensions.final
class KeyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_EXPIRATION_PERIOD_IN_DAYS_FIELD_NUMBER: builtins.int
    key_expiration_period_in_days: builtins.int
    def __init__(
        self,
        *,
        key_expiration_period_in_days: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_expiration_period_in_days", b"key_expiration_period_in_days"]) -> None: ...

global___KeyPolicy = KeyPolicy

@typing_extensions.final
class ImmutableStorageAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    IMMUTABILITY_POLICY_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def immutability_policy(self) -> global___AccountImmutabilityPolicyProperties: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        immutability_policy: global___AccountImmutabilityPolicyProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["immutability_policy", b"immutability_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "immutability_policy", b"immutability_policy"]) -> None: ...

global___ImmutableStorageAccount = ImmutableStorageAccount

@typing_extensions.final
class AccountImmutabilityPolicyProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PROTECTED_APPEND_WRITES_FIELD_NUMBER: builtins.int
    IMMUTABILITY_PERIOD_SINCE_CREATION_IN_DAYS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    allow_protected_append_writes: builtins.bool
    immutability_period_since_creation_in_days: builtins.int
    state: builtins.str
    def __init__(
        self,
        *,
        allow_protected_append_writes: builtins.bool = ...,
        immutability_period_since_creation_in_days: builtins.int = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_protected_append_writes", b"allow_protected_append_writes", "immutability_period_since_creation_in_days", b"immutability_period_since_creation_in_days", "state", b"state"]) -> None: ...

global___AccountImmutabilityPolicyProperties = AccountImmutabilityPolicyProperties

@typing_extensions.final
class Encryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_FIELD_NUMBER: builtins.int
    KEY_SOURCE_FIELD_NUMBER: builtins.int
    KEYVAULTPROPERTIES_FIELD_NUMBER: builtins.int
    REQUIRE_INFRASTRUCTURE_ENCRYPTION_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    @property
    def identity(self) -> global___EncryptionIdentity: ...
    key_source: builtins.str
    @property
    def keyvaultproperties(self) -> global___KeyVaultProperties: ...
    require_infrastructure_encryption: builtins.bool
    @property
    def services(self) -> global___EncryptionServices: ...
    def __init__(
        self,
        *,
        identity: global___EncryptionIdentity | None = ...,
        key_source: builtins.str = ...,
        keyvaultproperties: global___KeyVaultProperties | None = ...,
        require_infrastructure_encryption: builtins.bool = ...,
        services: global___EncryptionServices | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "keyvaultproperties", b"keyvaultproperties", "services", b"services"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "key_source", b"key_source", "keyvaultproperties", b"keyvaultproperties", "require_infrastructure_encryption", b"require_infrastructure_encryption", "services", b"services"]) -> None: ...

global___Encryption = Encryption

@typing_extensions.final
class EncryptionServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOB_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    QUEUE_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    @property
    def blob(self) -> global___EncryptionService: ...
    @property
    def file(self) -> global___EncryptionService: ...
    @property
    def queue(self) -> global___EncryptionService: ...
    @property
    def table(self) -> global___EncryptionService: ...
    def __init__(
        self,
        *,
        blob: global___EncryptionService | None = ...,
        file: global___EncryptionService | None = ...,
        queue: global___EncryptionService | None = ...,
        table: global___EncryptionService | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["blob", b"blob", "file", b"file", "queue", b"queue", "table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob", b"blob", "file", b"file", "queue", b"queue", "table", b"table"]) -> None: ...

global___EncryptionServices = EncryptionServices

@typing_extensions.final
class EncryptionService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    KEY_TYPE_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    key_type: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        key_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "key_type", b"key_type"]) -> None: ...

global___EncryptionService = EncryptionService

@typing_extensions.final
class KeyVaultProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYNAME_FIELD_NUMBER: builtins.int
    KEYVAULTURI_FIELD_NUMBER: builtins.int
    KEYVERSION_FIELD_NUMBER: builtins.int
    keyname: builtins.str
    keyvaulturi: builtins.str
    keyversion: builtins.str
    def __init__(
        self,
        *,
        keyname: builtins.str = ...,
        keyvaulturi: builtins.str = ...,
        keyversion: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyname", b"keyname", "keyvaulturi", b"keyvaulturi", "keyversion", b"keyversion"]) -> None: ...

global___KeyVaultProperties = KeyVaultProperties

@typing_extensions.final
class EncryptionIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_IDENTITY_CLIENT_ID_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    federated_identity_client_id: builtins.str
    user_assigned_identity: builtins.str
    def __init__(
        self,
        *,
        federated_identity_client_id: builtins.str = ...,
        user_assigned_identity: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["federated_identity_client_id", b"federated_identity_client_id", "user_assigned_identity", b"user_assigned_identity"]) -> None: ...

global___EncryptionIdentity = EncryptionIdentity

@typing_extensions.final
class CustomDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    USE_SUB_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    use_sub_domain_name: builtins.bool
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        use_sub_domain_name: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "use_sub_domain_name", b"use_sub_domain_name"]) -> None: ...

global___CustomDomain = CustomDomain

@typing_extensions.final
class AzureFilesIdentityBasedAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_DIRECTORY_PROPERTIES_FIELD_NUMBER: builtins.int
    DEFAULT_SHARE_PERMISSION_FIELD_NUMBER: builtins.int
    DIRECTORY_SERVICE_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def active_directory_properties(self) -> global___ActiveDirectoryProperties: ...
    default_share_permission: builtins.str
    directory_service_options: builtins.str
    def __init__(
        self,
        *,
        active_directory_properties: global___ActiveDirectoryProperties | None = ...,
        default_share_permission: builtins.str = ...,
        directory_service_options: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["active_directory_properties", b"active_directory_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active_directory_properties", b"active_directory_properties", "default_share_permission", b"default_share_permission", "directory_service_options", b"directory_service_options"]) -> None: ...

global___AzureFilesIdentityBasedAuthentication = AzureFilesIdentityBasedAuthentication

@typing_extensions.final
class ActiveDirectoryProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_TYPE_FIELD_NUMBER: builtins.int
    AZURE_STORAGE_SID_FIELD_NUMBER: builtins.int
    DOMAIN_GUID_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    DOMAIN_SID_FIELD_NUMBER: builtins.int
    FOREST_NAME_FIELD_NUMBER: builtins.int
    NET_BIOS_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    SAM_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    account_type: builtins.str
    azure_storage_sid: builtins.str
    domain_guid: builtins.str
    domain_name: builtins.str
    domain_sid: builtins.str
    forest_name: builtins.str
    net_bios_domain_name: builtins.str
    sam_account_name: builtins.str
    def __init__(
        self,
        *,
        account_type: builtins.str = ...,
        azure_storage_sid: builtins.str = ...,
        domain_guid: builtins.str = ...,
        domain_name: builtins.str = ...,
        domain_sid: builtins.str = ...,
        forest_name: builtins.str = ...,
        net_bios_domain_name: builtins.str = ...,
        sam_account_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_type", b"account_type", "azure_storage_sid", b"azure_storage_sid", "domain_guid", b"domain_guid", "domain_name", b"domain_name", "domain_sid", b"domain_sid", "forest_name", b"forest_name", "net_bios_domain_name", b"net_bios_domain_name", "sam_account_name", b"sam_account_name"]) -> None: ...

global___ActiveDirectoryProperties = ActiveDirectoryProperties

@typing_extensions.final
class Identity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___Identity = Identity

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PubsubLiteReservationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubLiteReservationXTimeouts = PubsubLiteReservationXTimeouts

@typing_extensions.final
class PubsubLiteReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    THROUGHPUT_CAPACITY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    throughput_capacity: builtins.float
    @property
    def timeouts(self) -> global___PubsubLiteReservationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        throughput_capacity: builtins.float = ...,
        timeouts: global___PubsubLiteReservationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "throughput_capacity", b"throughput_capacity", "timeouts", b"timeouts"]) -> None: ...

global___PubsubLiteReservation = PubsubLiteReservation

@typing_extensions.final
class PubsubLiteSubscriptionXDeliveryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_REQUIREMENT_FIELD_NUMBER: builtins.int
    delivery_requirement: builtins.str
    def __init__(
        self,
        *,
        delivery_requirement: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_requirement", b"delivery_requirement"]) -> None: ...

global___PubsubLiteSubscriptionXDeliveryConfig = PubsubLiteSubscriptionXDeliveryConfig

@typing_extensions.final
class PubsubLiteSubscriptionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubLiteSubscriptionXTimeouts = PubsubLiteSubscriptionXTimeouts

@typing_extensions.final
class PubsubLiteSubscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    DELIVERY_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    topic: builtins.str
    zone: builtins.str
    @property
    def delivery_config(self) -> global___PubsubLiteSubscriptionXDeliveryConfig: ...
    @property
    def timeouts(self) -> global___PubsubLiteSubscriptionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        topic: builtins.str = ...,
        zone: builtins.str = ...,
        delivery_config: global___PubsubLiteSubscriptionXDeliveryConfig | None = ...,
        timeouts: global___PubsubLiteSubscriptionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_config", b"delivery_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_config", b"delivery_config", "id", b"id", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts", "topic", b"topic", "zone", b"zone"]) -> None: ...

global___PubsubLiteSubscription = PubsubLiteSubscription

@typing_extensions.final
class PubsubLiteTopicXPartitionConfigXCapacity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLISH_MIB_PER_SEC_FIELD_NUMBER: builtins.int
    SUBSCRIBE_MIB_PER_SEC_FIELD_NUMBER: builtins.int
    publish_mib_per_sec: builtins.float
    subscribe_mib_per_sec: builtins.float
    def __init__(
        self,
        *,
        publish_mib_per_sec: builtins.float = ...,
        subscribe_mib_per_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["publish_mib_per_sec", b"publish_mib_per_sec", "subscribe_mib_per_sec", b"subscribe_mib_per_sec"]) -> None: ...

global___PubsubLiteTopicXPartitionConfigXCapacity = PubsubLiteTopicXPartitionConfigXCapacity

@typing_extensions.final
class PubsubLiteTopicXPartitionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    count: builtins.float
    @property
    def capacity(self) -> global___PubsubLiteTopicXPartitionConfigXCapacity: ...
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        capacity: global___PubsubLiteTopicXPartitionConfigXCapacity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capacity", b"capacity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "count", b"count"]) -> None: ...

global___PubsubLiteTopicXPartitionConfig = PubsubLiteTopicXPartitionConfig

@typing_extensions.final
class PubsubLiteTopicXReservationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THROUGHPUT_RESERVATION_FIELD_NUMBER: builtins.int
    throughput_reservation: builtins.str
    def __init__(
        self,
        *,
        throughput_reservation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["throughput_reservation", b"throughput_reservation"]) -> None: ...

global___PubsubLiteTopicXReservationConfig = PubsubLiteTopicXReservationConfig

@typing_extensions.final
class PubsubLiteTopicXRetentionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PER_PARTITION_BYTES_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    per_partition_bytes: builtins.str
    period: builtins.str
    def __init__(
        self,
        *,
        per_partition_bytes: builtins.str = ...,
        period: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["per_partition_bytes", b"per_partition_bytes", "period", b"period"]) -> None: ...

global___PubsubLiteTopicXRetentionConfig = PubsubLiteTopicXRetentionConfig

@typing_extensions.final
class PubsubLiteTopicXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubLiteTopicXTimeouts = PubsubLiteTopicXTimeouts

@typing_extensions.final
class PubsubLiteTopic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    PARTITION_CONFIG_FIELD_NUMBER: builtins.int
    RESERVATION_CONFIG_FIELD_NUMBER: builtins.int
    RETENTION_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    zone: builtins.str
    @property
    def partition_config(self) -> global___PubsubLiteTopicXPartitionConfig: ...
    @property
    def reservation_config(self) -> global___PubsubLiteTopicXReservationConfig: ...
    @property
    def retention_config(self) -> global___PubsubLiteTopicXRetentionConfig: ...
    @property
    def timeouts(self) -> global___PubsubLiteTopicXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        zone: builtins.str = ...,
        partition_config: global___PubsubLiteTopicXPartitionConfig | None = ...,
        reservation_config: global___PubsubLiteTopicXReservationConfig | None = ...,
        retention_config: global___PubsubLiteTopicXRetentionConfig | None = ...,
        timeouts: global___PubsubLiteTopicXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["partition_config", b"partition_config", "reservation_config", b"reservation_config", "resource_info", b"resource_info", "retention_config", b"retention_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "partition_config", b"partition_config", "project", b"project", "region", b"region", "reservation_config", b"reservation_config", "resource_info", b"resource_info", "retention_config", b"retention_config", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___PubsubLiteTopic = PubsubLiteTopic

@typing_extensions.final
class PubsubSchemaXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___PubsubSchemaXTimeouts = PubsubSchemaXTimeouts

@typing_extensions.final
class PubsubSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFINITION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    definition: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    type: builtins.str
    @property
    def timeouts(self) -> global___PubsubSchemaXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        definition: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        type: builtins.str = ...,
        timeouts: global___PubsubSchemaXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___PubsubSchema = PubsubSchema

@typing_extensions.final
class PubsubSubscriptionXDeadLetterPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEAD_LETTER_TOPIC_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_ATTEMPTS_FIELD_NUMBER: builtins.int
    dead_letter_topic: builtins.str
    max_delivery_attempts: builtins.float
    def __init__(
        self,
        *,
        dead_letter_topic: builtins.str = ...,
        max_delivery_attempts: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dead_letter_topic", b"dead_letter_topic", "max_delivery_attempts", b"max_delivery_attempts"]) -> None: ...

global___PubsubSubscriptionXDeadLetterPolicy = PubsubSubscriptionXDeadLetterPolicy

@typing_extensions.final
class PubsubSubscriptionXExpirationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TTL_FIELD_NUMBER: builtins.int
    ttl: builtins.str
    def __init__(
        self,
        *,
        ttl: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ttl", b"ttl"]) -> None: ...

global___PubsubSubscriptionXExpirationPolicy = PubsubSubscriptionXExpirationPolicy

@typing_extensions.final
class PubsubSubscriptionXPushConfigXOidcToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    audience: builtins.str
    service_account_email: builtins.str
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        service_account_email: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "service_account_email", b"service_account_email"]) -> None: ...

global___PubsubSubscriptionXPushConfigXOidcToken = PubsubSubscriptionXPushConfigXOidcToken

@typing_extensions.final
class PubsubSubscriptionXPushConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ATTRIBUTES_FIELD_NUMBER: builtins.int
    PUSH_ENDPOINT_FIELD_NUMBER: builtins.int
    OIDC_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    push_endpoint: builtins.str
    @property
    def oidc_token(self) -> global___PubsubSubscriptionXPushConfigXOidcToken: ...
    def __init__(
        self,
        *,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        push_endpoint: builtins.str = ...,
        oidc_token: global___PubsubSubscriptionXPushConfigXOidcToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["oidc_token", b"oidc_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "oidc_token", b"oidc_token", "push_endpoint", b"push_endpoint"]) -> None: ...

global___PubsubSubscriptionXPushConfig = PubsubSubscriptionXPushConfig

@typing_extensions.final
class PubsubSubscriptionXRetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAXIMUM_BACKOFF_FIELD_NUMBER: builtins.int
    MINIMUM_BACKOFF_FIELD_NUMBER: builtins.int
    maximum_backoff: builtins.str
    minimum_backoff: builtins.str
    def __init__(
        self,
        *,
        maximum_backoff: builtins.str = ...,
        minimum_backoff: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["maximum_backoff", b"maximum_backoff", "minimum_backoff", b"minimum_backoff"]) -> None: ...

global___PubsubSubscriptionXRetryPolicy = PubsubSubscriptionXRetryPolicy

@typing_extensions.final
class PubsubSubscriptionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubSubscriptionXTimeouts = PubsubSubscriptionXTimeouts

@typing_extensions.final
class PubsubSubscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACK_DEADLINE_SECONDS_FIELD_NUMBER: builtins.int
    ENABLE_EXACTLY_ONCE_DELIVERY_FIELD_NUMBER: builtins.int
    ENABLE_MESSAGE_ORDERING_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MESSAGE_RETENTION_DURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RETAIN_ACKED_MESSAGES_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    DEAD_LETTER_POLICY_FIELD_NUMBER: builtins.int
    EXPIRATION_POLICY_FIELD_NUMBER: builtins.int
    PUSH_CONFIG_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ack_deadline_seconds: builtins.float
    enable_exactly_once_delivery: builtins.bool
    enable_message_ordering: builtins.bool
    filter: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    message_retention_duration: builtins.str
    name: builtins.str
    project: builtins.str
    retain_acked_messages: builtins.bool
    topic: builtins.str
    @property
    def dead_letter_policy(self) -> global___PubsubSubscriptionXDeadLetterPolicy: ...
    @property
    def expiration_policy(self) -> global___PubsubSubscriptionXExpirationPolicy: ...
    @property
    def push_config(self) -> global___PubsubSubscriptionXPushConfig: ...
    @property
    def retry_policy(self) -> global___PubsubSubscriptionXRetryPolicy: ...
    @property
    def timeouts(self) -> global___PubsubSubscriptionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ack_deadline_seconds: builtins.float = ...,
        enable_exactly_once_delivery: builtins.bool = ...,
        enable_message_ordering: builtins.bool = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        message_retention_duration: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        retain_acked_messages: builtins.bool = ...,
        topic: builtins.str = ...,
        dead_letter_policy: global___PubsubSubscriptionXDeadLetterPolicy | None = ...,
        expiration_policy: global___PubsubSubscriptionXExpirationPolicy | None = ...,
        push_config: global___PubsubSubscriptionXPushConfig | None = ...,
        retry_policy: global___PubsubSubscriptionXRetryPolicy | None = ...,
        timeouts: global___PubsubSubscriptionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dead_letter_policy", b"dead_letter_policy", "expiration_policy", b"expiration_policy", "push_config", b"push_config", "resource_info", b"resource_info", "retry_policy", b"retry_policy", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_deadline_seconds", b"ack_deadline_seconds", "dead_letter_policy", b"dead_letter_policy", "enable_exactly_once_delivery", b"enable_exactly_once_delivery", "enable_message_ordering", b"enable_message_ordering", "expiration_policy", b"expiration_policy", "filter", b"filter", "id", b"id", "labels", b"labels", "message_retention_duration", b"message_retention_duration", "name", b"name", "project", b"project", "push_config", b"push_config", "resource_info", b"resource_info", "retain_acked_messages", b"retain_acked_messages", "retry_policy", b"retry_policy", "timeouts", b"timeouts", "topic", b"topic"]) -> None: ...

global___PubsubSubscription = PubsubSubscription

@typing_extensions.final
class PubsubSubscriptionIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PubsubSubscriptionIamBindingXCondition = PubsubSubscriptionIamBindingXCondition

@typing_extensions.final
class PubsubSubscriptionIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    subscription: builtins.str
    @property
    def condition(self) -> global___PubsubSubscriptionIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        subscription: builtins.str = ...,
        condition: global___PubsubSubscriptionIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "subscription", b"subscription"]) -> None: ...

global___PubsubSubscriptionIamBinding = PubsubSubscriptionIamBinding

@typing_extensions.final
class PubsubSubscriptionIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PubsubSubscriptionIamMemberXCondition = PubsubSubscriptionIamMemberXCondition

@typing_extensions.final
class PubsubSubscriptionIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    subscription: builtins.str
    @property
    def condition(self) -> global___PubsubSubscriptionIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        subscription: builtins.str = ...,
        condition: global___PubsubSubscriptionIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "subscription", b"subscription"]) -> None: ...

global___PubsubSubscriptionIamMember = PubsubSubscriptionIamMember

@typing_extensions.final
class PubsubSubscriptionIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    subscription: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        subscription: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "subscription", b"subscription"]) -> None: ...

global___PubsubSubscriptionIamPolicy = PubsubSubscriptionIamPolicy

@typing_extensions.final
class PubsubTopicXMessageStoragePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_PERSISTENCE_REGIONS_FIELD_NUMBER: builtins.int
    @property
    def allowed_persistence_regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_persistence_regions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_persistence_regions", b"allowed_persistence_regions"]) -> None: ...

global___PubsubTopicXMessageStoragePolicy = PubsubTopicXMessageStoragePolicy

@typing_extensions.final
class PubsubTopicXSchemaSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCODING_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    encoding: builtins.str
    schema: builtins.str
    def __init__(
        self,
        *,
        encoding: builtins.str = ...,
        schema: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encoding", b"encoding", "schema", b"schema"]) -> None: ...

global___PubsubTopicXSchemaSettings = PubsubTopicXSchemaSettings

@typing_extensions.final
class PubsubTopicXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PubsubTopicXTimeouts = PubsubTopicXTimeouts

@typing_extensions.final
class PubsubTopic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MESSAGE_RETENTION_DURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    MESSAGE_STORAGE_POLICY_FIELD_NUMBER: builtins.int
    SCHEMA_SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    kms_key_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    message_retention_duration: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def message_storage_policy(self) -> global___PubsubTopicXMessageStoragePolicy: ...
    @property
    def schema_settings(self) -> global___PubsubTopicXSchemaSettings: ...
    @property
    def timeouts(self) -> global___PubsubTopicXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        message_retention_duration: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        message_storage_policy: global___PubsubTopicXMessageStoragePolicy | None = ...,
        schema_settings: global___PubsubTopicXSchemaSettings | None = ...,
        timeouts: global___PubsubTopicXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["message_storage_policy", b"message_storage_policy", "resource_info", b"resource_info", "schema_settings", b"schema_settings", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "kms_key_name", b"kms_key_name", "labels", b"labels", "message_retention_duration", b"message_retention_duration", "message_storage_policy", b"message_storage_policy", "name", b"name", "project", b"project", "resource_info", b"resource_info", "schema_settings", b"schema_settings", "timeouts", b"timeouts"]) -> None: ...

global___PubsubTopic = PubsubTopic

@typing_extensions.final
class PubsubTopicIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PubsubTopicIamBindingXCondition = PubsubTopicIamBindingXCondition

@typing_extensions.final
class PubsubTopicIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    topic: builtins.str
    @property
    def condition(self) -> global___PubsubTopicIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        topic: builtins.str = ...,
        condition: global___PubsubTopicIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "topic", b"topic"]) -> None: ...

global___PubsubTopicIamBinding = PubsubTopicIamBinding

@typing_extensions.final
class PubsubTopicIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PubsubTopicIamMemberXCondition = PubsubTopicIamMemberXCondition

@typing_extensions.final
class PubsubTopicIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    topic: builtins.str
    @property
    def condition(self) -> global___PubsubTopicIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        topic: builtins.str = ...,
        condition: global___PubsubTopicIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "topic", b"topic"]) -> None: ...

global___PubsubTopicIamMember = PubsubTopicIamMember

@typing_extensions.final
class PubsubTopicIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    topic: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        topic: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "topic", b"topic"]) -> None: ...

global___PubsubTopicIamPolicy = PubsubTopicIamPolicy
